//@line 4 "/builds/worker/l10n-esr52/pl/calendar/lightning-l10n.js"

//@line 6 "/builds/worker/l10n-esr52/pl/calendar/lightning-l10n.js"

//@line 9 "/builds/worker/l10n-esr52/pl/calendar/lightning-l10n.js"
pref("calendar.week.start", 1);

//@line 12 "/builds/worker/l10n-esr52/pl/calendar/lightning-l10n.js"
pref("calendar.week.d0sundaysoff", true);
pref("calendar.week.d1mondaysoff", false);
pref("calendar.week.d2tuesdaysoff", false);
pref("calendar.week.d3wednesdaysoff", false);
pref("calendar.week.d4thursdaysoff", false);
pref("calendar.week.d5fridaysoff", false);
pref("calendar.week.d6saturdaysoff", true);

pref("general.useragent.locale", "pl");

//@line 23 "/builds/worker/l10n-esr52/pl/calendar/lightning-l10n.js"
pref("calendar.categories.names", "Rocznica,Urodziny,Biznes,Rozmowy,Klienci,Konkurencja,Ulubione,Kontynuacja,Prezenty,Święta,Pomysły,Problemy,Spotkanie,Różne,Osobiste,Projekty,Święto państwowe,Dostawcy,Podróż,Wakacje");
